@@ -8,11 +8,14 @@ from .functions import (
     create_mock_engine,
     database_exists,
     defer_except,
+    dependent_objects,
     drop_database,
     escape_like,
     get_columns,
     get_declarative_base,
     get_primary_keys,
+    get_referencing_foreign_keys,
+    get_tables,
     identity,
     mock_engine,
     naturally_equivalent,
@@ -29,6 +32,7 @@ from .listeners import (
 from .merge import merge, Merger
 from .generic import generic_relationship
 from .proxy_dict import ProxyDict, proxy_dict
+from .query_chain import QueryChain
 from .types import (
     ArrowType,
     Choice,
@@ -60,7 +64,7 @@ from .types import (
 )
 
 
-__version__ = '0.25.4'
+__version__ = '0.26.0'
 
 
 __all__ = (
@@ -71,6 +75,7 @@ __all__ = (
     create_mock_engine,
     database_exists,
     defer_except,
+    dependent_objects,
     drop_database,
     escape_like,
     force_auto_coercion,
@@ -80,6 +85,8 @@ __all__ = (
     get_columns,
     get_declarative_base,
     get_primary_keys,
+    get_referencing_foreign_keys,
+    get_tables,
     identity,
     instrumented_list,
     merge,
@@ -114,6 +121,7 @@ __all__ = (
     PhoneNumber,
     PhoneNumberType,
     ProxyDict,
+    QueryChain,
     ScalarListException,
     ScalarListType,
     TimezoneType,
