@@ -12,9 +12,12 @@ from .database import (
     non_indexed_foreign_keys,
 )
 from .orm import (
+    dependent_objects,
     get_columns,
     get_declarative_base,
     get_primary_keys,
+    get_referencing_foreign_keys,
+    get_tables,
     getdotattr,
     has_changes,
     identity,
@@ -28,11 +31,14 @@ __all__ = (
     'create_mock_engine',
     'database_exists',
     'defer_except',
+    'dependent_objects',
     'drop_database',
     'escape_like',
     'get_columns',
     'get_declarative_base',
     'get_primary_keys',
+    'get_referencing_foreign_keys',
+    'get_tables',
     'getdotattr',
     'has_changes',
     'identity',
