@@ -3,6 +3,7 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 from functools import partial
+from itertools import groupby
 from inspect import isclass
 from operator import attrgetter
 import sqlalchemy as sa
@@ -11,7 +12,168 @@ from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.query import _ColumnEntity
+from sqlalchemy.orm.session import object_session
 from sqlalchemy.orm.util import AliasedInsp
+from ..query_chain import QueryChain
+
+
+def dependent_objects(obj, foreign_keys=None):
+    """
+    Return a QueryChain that iterates through all dependent objects for given
+    SQLAlchemy object.
+
+    Consider a User object is referenced in various articles and also in
+    various orders. Getting all these dependent objects is as easy as:
+
+    ::
+
+        from sqlalchemy_utils import dependent_objects
+
+
+        dependent_objects(user)
+
+
+    If you expect an object to have lots of dependent_objects it might be good
+    to limit the results::
+
+
+        dependent_objects(user).limit(5)
+
+
+
+    The common use case is checking for all restrict dependent objects before
+    deleting parent object and inform the user if there are dependent objects
+    with ondelete='RESTRICT' foreign keys. If this kind of checking is not used
+    it will lead to nasty IntegrityErrors being raised.
+
+    In the following example we delete given user if it doesn't have any
+    foreign key restricted dependent objects.
+
+    ::
+
+
+        from sqlalchemy_utils import get_referencing_foreign_keys
+
+
+        user = session.query(User).get(some_user_id)
+
+
+        deps = list(
+            dependent_objects(
+                user,
+                (
+                    fk for fk in get_referencing_foreign_keys(User)
+                    # On most databases RESTRICT is the default mode hence we
+                    # check for None values also
+                    if fk.ondelete == 'RESTRICT' or fk.ondelete is None
+                )
+            ).limit(5)
+        )
+
+        if deps:
+            # Do something to inform the user
+            pass
+        else:
+            session.delete(user)
+
+
+    :param obj: SQLAlchemy declarative model object
+    :param foreign_keys:
+        A sequence of foreign keys to use for searching the dependent_objects
+        for given object. By default this is None, indicating that all foreign
+        keys referencing the object will be used.
+
+    .. note::
+        This function does not support exotic mappers that use multiple tables
+
+    .. seealso:: :func:`get_referencing_foreign_keys`
+
+    .. versionadded: 0.26.0
+    """
+    if foreign_keys is None:
+        foreign_keys = get_referencing_foreign_keys(obj)
+
+    session = object_session(obj)
+
+    foreign_keys = sorted(
+        foreign_keys, key=lambda key: key.constraint.table.name
+    )
+    chain = QueryChain([])
+    classes = obj.__class__._decl_class_registry
+
+    for table, keys in groupby(foreign_keys, lambda key: key.constraint.table):
+        for class_ in classes.values():
+            if hasattr(class_, '__table__') and class_.__table__ == table:
+                criteria = []
+                visited_constraints = []
+                for key in keys:
+                    if key.constraint not in visited_constraints:
+                        visited_constraints.append(key.constraint)
+                        subcriteria = [
+                            getattr(class_, column.key) ==
+                            getattr(
+                                obj,
+                                key.constraint.elements[index].column.key
+                            )
+                            for index, column
+                            in enumerate(key.constraint.columns)
+                        ]
+                        criteria.append(sa.and_(*subcriteria))
+
+                query = session.query(class_).filter(
+                    sa.or_(
+                        *criteria
+                    )
+                )
+                chain.queries.append(query)
+        return chain
+
+
+def get_referencing_foreign_keys(mixed):
+    """
+    Returns referencing foreign keys for given Table object or declarative
+    class.
+
+    :param mixed:
+        SA Table object or SA declarative class
+
+    ::
+
+        get_referencing_foreign_keys(User)  # set([ForeignKey('user.id')])
+
+        get_referencing_foreign_keys(User.__table__)
+
+
+    This function also understands inheritance. This means it returns
+    all foreign keys that reference any table in the class inheritance tree.
+
+    Let's say you have three classes which use joined table inheritance,
+    namely TextItem, Article and BlogPost with Article and BlogPost inheriting
+    TextItem.
+
+    ::
+
+        # This will check all foreign keys that reference either article table
+        # or textitem table.
+        get_referencing_foreign_keys(Article)
+
+    .. seealso:: :func:`get_tables`
+    """
+    if isinstance(mixed, sa.Table):
+        tables = [mixed]
+    else:
+        tables = get_tables(mixed)
+
+    referencing_foreign_keys = set()
+
+    for table in mixed.metadata.tables.values():
+        if table not in tables:
+            for constraint in table.constraints:
+                if isinstance(constraint, sa.sql.schema.ForeignKeyConstraint):
+                    for fk in constraint.elements:
+                        if any(fk.references(t) for t in tables):
+                            referencing_foreign_keys.add(fk)
+    return referencing_foreign_keys
 
 
 def get_primary_keys(mixed):
@@ -34,7 +196,7 @@ def get_primary_keys(mixed):
 
         get_primary_keys(sa.orm.aliased(User))
 
-        get_primary_keys(sa.orm.alised(User.__table__))
+        get_primary_keys(sa.orm.aliased(User.__table__))
 
 
     .. versionchanged: 0.25.3
@@ -45,11 +207,43 @@ def get_primary_keys(mixed):
 
     .. seealso:: :func:`get_columns`
     """
-    columns = OrderedDict()
-    for key, column in get_columns(mixed).items():
-        if column.primary_key:
-            columns[key] = column
-    return columns
+    return OrderedDict(
+        (
+            (key, column) for key, column in get_columns(mixed).items()
+            if column.primary_key
+        )
+    )
+
+
+def get_tables(mixed):
+    """
+    Return a list of tables associated with given SQLAlchemy object.
+
+    Let's say we have three classes which use joined table inheritance
+    TextItem, Article and BlogPost. Article and BlogPost inherit TextItem.
+
+    ::
+
+        get_tables(Article)  # [Table('article', ...), Table('text_item')]
+
+        get_tables(Article())
+
+        get_tables(Article.__mapper__)
+
+
+    .. versionadded: 0.26.0
+
+    :param mixed:
+        SQLAlchemy Mapper / Declarative class or a SA Alias object wrapping
+        any of these objects.
+    """
+    if isinstance(mixed, sa.orm.util.AliasedClass):
+        mapper = sa.inspect(mixed).mapper
+    else:
+        if not isclass(mixed):
+            mixed = mixed.__class__
+        mapper = sa.inspect(mixed)
+    return mapper.tables
 
 
 def get_columns(mixed):
@@ -218,7 +412,9 @@ def query_entities(query):
         query_entities(query)  # <Category>
 
 
-    This function also supports queries with joins:
+    This function also supports queries with joins.
+
+    ::
 
 
         query = session.query(Category).join(Article)
